#[non_exhaustive]pub struct DcBranchData {
pub from_bus: Vec<usize>,
pub to_bus: Vec<usize>,
pub b: Vec<f64>,
pub shift: Vec<f64>,
pub f_max: Vec<f64>,
pub angle_min: Vec<f64>,
pub angle_max: Vec<f64>,
pub source_rows: Vec<usize>,
pub skipped_zero_impedance: Vec<usize>,
}Expand description
Branch data in active branch column order.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.from_bus: Vec<usize>to_bus: Vec<usize>b: Vec<f64>Branch coefficient in the selected power unit per radian.
shift: Vec<f64>Phase shift in radians. Zero under DcConvention::PaperPure.
f_max: Vec<f64>Thermal limit in the selected power unit. Zero means unlimited.
angle_min: Vec<f64>Branch angle bounds in radians.
angle_max: Vec<f64>source_rows: Vec<usize>Branch column to source branch row.
skipped_zero_impedance: Vec<usize>Source branch rows omitted because their reactance was zero.